@@ -7,8 +7,7 @@ import com.google.gwt.core.client.EntryPoint;
 /**
  * Entry point classes define <code>onModuleLoad()</code>.
  */
-//public class WsMail_Widget implements EntryPoint {
-public class WsMail_Widget {
+public class WsMail_Widget implements EntryPoint {
 	/**
 	 * This is the entry point method.
 	 */
